import pyautogui
import time


countdown = [5, 4, 3, 2, 1]


class ReadFile:
    def __init__(self, file):
        self.file = file

    def spam(self):
        f = open(self.file, "r")

        print("""
╔═══╗─────────╔══╗───╔╗
║╔═╗║─────────║╔╗║──╔╝╚╗
║╚══╦══╦══╦╗╔╗║╚╝╚╦═╩╗╔╝
╚══╗║╔╗║╔╗║╚╝║║╔═╗║╔╗║║
║╚═╝║╚╝║╔╗║║║║║╚═╝║╚╝║╚╗
╚═══╣╔═╩╝╚╩╩╩╝╚═══╩══╩═╝
────║║
────╚╝
	""")

        print(
            "To stop the program, move the curser to the upper left corner of the screen.")
        print("")

        for num in countdown:
            print(f"Starting in {num}...")
            time.sleep(1)

        print("Boom!")

        for line in f:
            pyautogui.typewrite(line)
            pyautogui.press("enter")


def spam(msg, count):

    print("""
╔═══╗─────────╔══╗───╔╗
║╔═╗║─────────║╔╗║──╔╝╚╗
║╚══╦══╦══╦╗╔╗║╚╝╚╦═╩╗╔╝
╚══╗║╔╗║╔╗║╚╝║║╔═╗║╔╗║║
║╚═╝║╚╝║╔╗║║║║║╚═╝║╚╝║╚╗
╚═══╣╔═╩╝╚╩╩╩╝╚═══╩══╩═╝
────║║
────╚╝
""")

    print("To stop the program, move the curser to the upper left corner of the screen.")
    print("")

    for num in countdown:
        print(f"Starting in {num}...")
        time.sleep(1)

    print("Boom!")

    for _ in range(int(count)):
        pyautogui.typewrite(msg)
        pyautogui.press("enter")



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()
with open("requirements.txt", "r") as fh:
    requirements = [line.strip() for line in fh]

setuptools.setup(
    name="spam-bot",
    version="0.0.3",
    author="Hirusha Pramuditha",
    author_email="hirushapramuditha26@gmail.com",
    description="Spam anything!",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/HirushaPramuditha/spam-bot",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
    install_requires=requirements,
)
